@@ -60,21 +60,13 @@ def set(assets,prestart,start,end,period,capital,file='backtest_file',verbose=Fa
         return None
     return bts
 
-def getShares(bts,asset):
+def get_shares(bts,asset):
     return bts['shares_'+asset]
 
-def getBalance(bts):
+def get_balance(bts):
     return bts['capital']
 
-def getAfforShares(bts,dbars,assetId,money=None,volumeStep=None):
-    if money==None:
-        money=bts['capital']
-    bars=dbars[assetId]
-    price=bars['close'].iloc[-1]
-    return se.getAfforShares(assetId,money,price,volumeStep)
 
-def downloadData(bts):
-    print("to do")
 
 ## assume-se que todos os ativos tem o mesmo numero de barras do ativo indice zero assets[0] no periodo de backtest
 sim_dates=[]
@@ -84,9 +76,9 @@ def startBckt(bts):
     assets=bts['assets']
     dbars=dict()
     for asset in assets:
-        dbars[asset]=se.getBars(asset,bts['prestart'],bts['start'],bts['type'])
+        dbars[asset]=se.get_bars(asset,bts['prestart'],bts['start'],bts['type'])
         bts['shares_'+asset]=0.0
-    bars=se.getBars(assets[0],bts['start'],bts['end'],bts['type'])
+    bars=se.get_bars(assets[0],bts['start'],bts['end'],bts['type'])
     
     sim_dates=bars['time']
    
@@ -118,7 +110,7 @@ def checkOrder(req,bts,bars):
     money=bts['capital']
     asset=req['symbol']
     volume=req['volume']
-    price=se.getLastPrice(bars)
+    price=se.get_last(bars)
     sell=se.isSellOrder(req)
 
     if sell:
@@ -143,7 +135,7 @@ def computeOrders(orders,bts,dbars):
         datesHist.append(sim_dates[bts['curr']])
         for asset in assets:
             bar=dbars[asset]
-            price=se.getLastPrice(bar)
+            price=se.get_last(bar)
             total_in_shares=total_in_shares+bts['shares_'+asset]*price # counts the value in asset with no order
         if bts['verbose']:
             print( 'No orders in time(',bts['curr'],') = ',sim_dates[bts['curr']],' capital=',bts['capital'], 'total in shares=',total_in_shares)
@@ -156,7 +148,7 @@ def computeOrders(orders,bts,dbars):
         if bar is None:
             print('Error accesing bar to compute order')
             return False
-        price=se.getLastPrice(bar)
+        price=se.get_last(bar)
         order=getOrder(orders,asset)
         if order==None: # if no order for that asset, go to the next
             total_in_shares=total_in_shares+bts['shares_'+asset]*price # counts the value in asset with no order
@@ -196,7 +188,7 @@ def getCurrBars(bts,dbars):
     for asset in assets:
         dbar=dbars[asset]
         #pega nova barra    
-        aux=se.getBars(asset,sim_dates[bts['curr']],1,bts['type']) # pega uma barra! daily or intraday
+        aux=se.get_bars(asset,sim_dates[bts['curr']],1,bts['type']) # pega uma barra! daily or intraday
         if not aux is None and not aux.empty:
             dbar=dbar.iloc[1:,] #remove barra mais antiga
             #adiciona nova barra
@@ -238,6 +230,8 @@ def checkBTS(bts):
         return False
 
 def run(trader,bts):
+    se.mt5se.inbacktest=True
+    se.mt5se.bts=bts
     balanceHist.clear()
     equityHist.clear()
     datesHist.clear()
@@ -254,7 +248,7 @@ def run(trader,bts):
         print("Starting at simulated date=",sim_dates[0]," len=",len(sim_dates))
     while not endedBckt(bts):
         #orders=trader.getNewInfo(dbars)
-        orders=trader.trade(bts,dbars)
+        orders=trader.trade(dbars)
         dbars=getCurrBars(bts,dbars)
         computeOrders(orders,bts,dbars)
         if bts['verbose']:
@@ -263,6 +257,7 @@ def run(trader,bts):
     print('End of backtest with ',bts['curr'],' bars,  saving equity file in ',bts['file'])
     trader.ending(dbars)
     df=saveEquityFile(bts)
+    se.mt5se.inbacktest=False
     return df
 
 
@@ -421,34 +416,33 @@ def __calcReturns(serie):
     evaluates a trader performance given its serie of historical equity value 
 """
 def evaluateEquitySerie(serie,threshold=0.5,riskFree=0.0):
-   if serie is None:
-      print("serie should be a list of observed market values of the portfolio, given daily")
-      return None
-   serie=__calcReturns(serie)
-   numberOfDays=len(serie)
-   if numberOfDays<30:
-      print("In order to perform evaluation, you should have at least 30 data points, but you got only ",numberOfDays)
-      return False
-
-   print("\n -----------------------   Backtest Report  ------------------------------- \n")
-   print("Total Return (%)={:.2f} in {} bars ".format(calcTotalReturn(serie)*100,numberOfDays))
-   print("Average Bar Return (%)={:.2f}  ".format(np.average(serie)*100))
-   #print("Annualized Return (%)={:.2f}".format(calcAnnualReturn(serie,numberOfDays)*100))
-   print("Std Deviation of returns (%) ={:.4f}".format(calcStdDev(serie)*100))
-   #print("Sharpe Ratio={:.4f} ".format(calcSharpeRatio(serie,riskFree)))
-   #print("Annualized Sharpe Ratio={:.4f} ".format(calcAnnualSharpeRatio(serie,riskFree,numberOfDays ))),
-   l1=0
+    if serie is None:
+        print("serie should be a list of observed market values of the portfolio, given daily")
+        return None
+    serie=__calcReturns(serie)
+    numberOfDays=len(serie)
+    if numberOfDays<30:
+        print("In order to perform evaluation, you should have at least 30 data points, but you got only ",numberOfDays)
+        return False
+    print("\n -----------------------   Backtest Report  ------------------------------- \n")
+    print("Total Return (%)={:.2f} in {} bars ".format(calcTotalReturn(serie)*100,numberOfDays))
+    print("Average Bar Return (%)={:.2f}  ".format(np.average(serie)*100))
+    #print("Annualized Return (%)={:.2f}".format(calcAnnualReturn(serie,numberOfDays)*100))
+    print("Std Deviation of returns (%) ={:.4f}".format(calcStdDev(serie)*100))
+    #print("Sharpe Ratio={:.4f} ".format(calcSharpeRatio(serie,riskFree)))
+    #print("Annualized Sharpe Ratio={:.4f} ".format(calcAnnualSharpeRatio(serie,riskFree,numberOfDays ))),
+    """ l1=0
    p1=ProbReturnGreaterThanThreshold(serie,l1)
    l2=0.1
    p2=ProbReturnGreaterThanThreshold(serie,l2)
    l3=0.2
    p3=ProbReturnGreaterThanThreshold(serie,l3)
    
-   #print("Probability that Annual Return is greater than ({:.1f}%) ={:.2f}%".format(100*l1, 100*p1))
-  # print("Probability that Annual Return is greater than ({:.1f}%) ={:.2f}%".format(100*l2, 100*p2,l2))
-   #print("Probability that Annual Return is greater than ({:.1f}%) ={:.2f}%".format(100*l3, 100*p3))
+   print("Probability that Annual Return is greater than ({:.1f}%) ={:.2f}%".format(100*l1, 100*p1))
+   print("Probability that Annual Return is greater than ({:.1f}%) ={:.2f}%".format(100*l2, 100*p2))
+   print("Probability that Annual Return is greater than ({:.1f}%) ={:.2f}%".format(100*l3, 100*p3))"""
 
-   print("\n ----------------------        End of Report     -------------------------------- \n")
+    print("\n ----------------------        End of Report     -------------------------------- \n")
 
 
 
